==> drumgizmo_0.9.8.1.orig.tar.gz: drumgizmo-0.9.8.1/plugingui/image.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            image.h
 *
 *  Sat Mar 16 15:05:08 CET 2013
 *  Copyright 2013 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#ifndef __DRUMGIZMO_IMAGE_H__
#define __DRUMGIZMO_IMAGE_H__

#include <string>

#include "colour.h"
#include "resource.h"

namespace GUI {

class Image {
public:
  Image(const char* data, size_t size);
  Image(std::string filename);
  ~Image();

  size_t width();
  size_t height();

  Colour getPixel(size_t x, size_t y);

private:
  void setError(int err);

  void load(const char* data, size_t size);

  size_t w, h;
  unsigned char *image_data;
};

};

#endif/*__DRUMGIZMO_IMAGE_H__*/

==> drumgizmo_0.9.10.orig.tar.gz: drumgizmo-0.9.10/plugingui/image.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            image.h
 *
 *  Sat Mar 16 15:05:08 CET 2013
 *  Copyright 2013 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#pragma once

#include <string>

#include "colour.h"
#include "resource.h"

namespace GUI {

class Image {
public:
	Image(const char* data, size_t size);
	Image(const std::string& filename);
	~Image();

	size_t width() const;
	size_t height() const;

	Colour getPixel(size_t x, size_t y) const;

private:
	void setError();

	void load(const char* data, size_t size);

	size_t _width, _height;
	unsigned char* image_data;
};

} // GUI::
